@@ -62,6 +62,8 @@ struct _GeditNotebookPrivate
 
 	GeditNotebookShowTabsModeType show_tabs_mode;
 
+	GtkCssProvider *css;
+
 	guint close_buttons_sensitive : 1;
 	guint ignore_focused_page_update : 1;
 };
@@ -167,6 +169,12 @@ gedit_notebook_dispose (GObject *object)
 		notebook->priv->ui_settings = NULL;
 	}
 
+	if (notebook->priv->css != NULL)
+	{
+		g_object_unref (notebook->priv->css);
+		notebook->priv->css = NULL;
+	}
+
 	G_OBJECT_CLASS (gedit_notebook_parent_class)->dispose (object);
 }
 
@@ -547,17 +555,6 @@ gedit_notebook_add_tab (GeditNotebook *nb,
 	}
 }
 
-static void
-remove_tab (GeditTab      *tab,
-            GeditNotebook *nb)
-{
-	gint position;
-
-	position = gtk_notebook_page_num (GTK_NOTEBOOK (nb), GTK_WIDGET (tab));
-
-	gtk_notebook_remove_page (GTK_NOTEBOOK (nb), position);
-}
-
 /**
  * gedit_notebook_move_tab:
  * @src: a #GeditNotebook
@@ -583,28 +580,11 @@ gedit_notebook_move_tab (GeditNotebook *src,
 
 	/* make sure the tab isn't destroyed while we move it */
 	g_object_ref (tab);
-	remove_tab (tab, src);
+	gtk_container_remove (GTK_CONTAINER (src), GTK_WIDGET (tab));
 	gedit_notebook_add_tab (dest, tab, dest_position, TRUE);
 	g_object_unref (tab);
 }
 
-/**
- * gedit_notebook_remove_tab:
- * @nb: a #GeditNotebook
- * @tab: a #GeditTab
- *
- * Removes @tab from @nb.
- */
-void
-gedit_notebook_remove_tab (GeditNotebook *nb,
-			   GeditTab      *tab)
-{
-	g_return_if_fail (GEDIT_IS_NOTEBOOK (nb));
-	g_return_if_fail (GEDIT_IS_TAB (tab));
-
-	remove_tab (tab, nb);
-}
-
 /**
  * gedit_notebook_remove_all_tabs:
  * @nb: a #GeditNotebook
@@ -613,15 +593,23 @@ gedit_notebook_remove_tab (GeditNotebook *nb,
  */
 void
 gedit_notebook_remove_all_tabs (GeditNotebook *nb)
-{	
+{
+	GList *tabs, *t;
+
 	g_return_if_fail (GEDIT_IS_NOTEBOOK (nb));
-	
+
 	g_list_free (nb->priv->focused_pages);
 	nb->priv->focused_pages = NULL;
 
-	gtk_container_foreach (GTK_CONTAINER (nb),
-			       (GtkCallback)remove_tab,
-			       nb);
+	/* Remove tabs in reverse order since it is faster
+	 * due to how gtknotebook works */
+	tabs = gtk_container_get_children (GTK_CONTAINER (nb));
+	for (t = g_list_last (tabs); t != NULL; t = t->prev)
+	{
+		gtk_container_remove (GTK_CONTAINER (nb), GTK_WIDGET (t->data));
+	}
+
+	g_list_free (tabs);
 }
 
 static void
@@ -677,4 +665,66 @@ gedit_notebook_get_close_buttons_sensitive (GeditNotebook *nb)
 	return nb->priv->close_buttons_sensitive;
 }
 
+static void
+remove_right_padding (GeditNotebook *nb)
+{
+	GtkStyleContext *context;
+	GtkBorder padding;
+	gchar *modified_style;
+	GError *error = NULL;
+	const gchar style[] =
+		".notebook {\n"
+		  "padding: %d 0 %d %d;\n"
+		"}";
+
+	/* FIXME: find out a css like way to do this, right now padding-right/left
+	  doesn't work */
+	context = gtk_widget_get_style_context (GTK_WIDGET (nb));
+	gtk_style_context_get_padding (context, gtk_style_context_get_state (context),
+	                               &padding);
+
+	modified_style = g_strdup_printf (style, padding.top, padding.bottom, padding.left);
+
+	/* make it as small as possible */
+	if (nb->priv->css == NULL)
+	{
+		nb->priv->css = gtk_css_provider_new ();
+	}
+
+	if (gtk_css_provider_load_from_data (nb->priv->css, modified_style, -1, &error))
+	{
+		gtk_style_context_add_provider (context,
+		                                GTK_STYLE_PROVIDER (nb->priv->css),
+		                                GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	}
+	else
+	{
+		g_warning ("%s", error->message);
+		g_error_free (error);
+	}
+
+	g_free (modified_style);
+}
+
+void
+gedit_notebook_collapse_border (GeditNotebook *nb,
+                                gboolean       collapse)
+{
+	g_return_if_fail (GEDIT_IS_NOTEBOOK (nb));
+
+	if (collapse)
+	{
+		remove_right_padding (nb);
+	}
+	/* if we made some modification put it back to the default state */
+	else if (nb->priv->css != NULL)
+	{
+		GtkStyleContext *context;
+
+		context = gtk_widget_get_style_context (GTK_WIDGET (nb));
+		gtk_style_context_remove_provider (context,
+		                                   GTK_STYLE_PROVIDER (nb->priv->css));
+	}
+}
+
 /* ex:set ts=8 noet: */
