@@ -280,8 +280,8 @@ class Manager:
     
     def build(self):
         callbacks = {
-            'on_new_tool_button_clicked'      : self.on_new_tool_button_clicked,
-            'on_remove_tool_button_clicked'   : self.on_remove_tool_button_clicked,
+            'on_action_add_tool_activated'    : self.on_action_add_tool_activated,
+            'on_action_remove_tool_activated' : self.on_action_remove_tool_activated,
             'on_tool_manager_dialog_response' : self.on_tool_manager_dialog_response,
             'on_tool_manager_dialog_focus_out': self.on_tool_manager_dialog_focus_out,
             'on_accelerator_key_press'        : self.on_accelerator_key_press,
@@ -295,15 +295,21 @@ class Manager:
         self.ui.add_from_file(os.path.join(self.datadir, 'ui', 'tools.ui'))
         self.ui.connect_signals(callbacks)
         self.dialog = self.ui.get_object('tool-manager-dialog')
-        
-        self.view = self.ui.get_object('view')
-        
+
+        self.view = self['view']
+
         self.__init_tools_model()
         self.__init_tools_view()
 
+        # join treeview and toolbar
+        context = self['scrolled_window1'].get_style_context()
+        context.set_junction_sides(Gtk.JunctionSides.BOTTOM)
+        context = self['toolbar1'].get_style_context()
+        context.set_junction_sides(Gtk.JunctionSides.TOP)
+
         for name in ['input', 'output', 'applicability', 'save-files']:
             self.__init_combobox(name)
-        
+
         self.do_update()
 
     def expand_from_doc(self, doc):
@@ -524,10 +530,10 @@ class Manager:
     def clear_fields(self):
         self['accelerator'].set_text('')
 
-	buf = self['commands'].get_buffer()
-	buf.begin_not_undoable_action()
-	buf.set_text('')
-	buf.end_not_undoable_action()
+        buf = self['commands'].get_buffer()
+        buf.begin_not_undoable_action()
+        buf.set_text('')
+        buf.end_not_undoable_action()
 
         for nm in ('input', 'output', 'applicability', 'save-files'):
             self[nm].set_active(0)
@@ -590,8 +596,8 @@ class Manager:
 
         removable = node is not None and node.is_local()
 
-        self['remove-tool-button'].set_sensitive(removable)
-        self['revert-tool-button'].set_sensitive(removable)
+        self['remove-tool-action'].set_sensitive(removable)
+        self['revert-tool-action'].set_sensitive(removable)
 
         if node is not None and node.is_global():
             self['remove-tool-button'].hide()
@@ -636,7 +642,7 @@ class Manager:
         
         return self.language_id_from_iter(piter)
 
-    def on_new_tool_button_clicked(self, button):
+    def on_action_add_tool_activated(self, action):
         self.save_current_tool()
         
         # block handlers while inserting a new item
@@ -668,7 +674,7 @@ class Manager:
 
         self.update_remove_revert()
 
-    def on_remove_tool_button_clicked(self, button):
+    def on_action_remove_tool_activated(self, action):
         piter, node = self.get_selected_tool()
 
         if not node:
@@ -681,7 +687,7 @@ class Manager:
                 self.remove_accelerator(node, shortcut)
                 self.add_accelerator(node)
 
-                self['revert-tool-button'].set_sensitive(False)
+                self['revert-tool-action'].set_sensitive(False)
                 self.fill_fields()
                 
                 self.tool_changed(node)
@@ -836,11 +842,11 @@ class Manager:
 
     def on_tool_manager_dialog_response(self, dialog, response):
         if response == Gtk.ResponseType.HELP:
-            Gedit.app_get_default().show_help(self.dialog, 'gedit', 'gedit-external-tools-plugin')
+            Gedit.app_get_default().show_help(self.dialog, 'gedit', 'gedit-plugins-external-tools')
             return
 
         self.on_tool_manager_dialog_focus_out(dialog, None)
-        
+
         self.dialog.destroy()
         self.dialog = None
         self.tools = None
