@@ -40,8 +40,6 @@ create_document (const gchar *filename,
                  const gchar *contents)
 {
 	GError *error = NULL;
-	GeditDocument *document;
-	gchar *uri;
 
 	if (!g_file_set_contents (filename, contents, -1, &error))
 	{
@@ -103,7 +101,6 @@ test_loader (const gchar *filename,
              gint         newline_type)
 {
 	GFile *file;
-	gchar *uri;
 	GeditDocument *document;
 
 	file = create_document (filename, contents);
@@ -237,8 +234,6 @@ int main (int   argc,
 	g_type_init ();
 	g_test_init (&argc, &argv, NULL);
 
-	gedit_prefs_manager_app_init ();
-
 	g_test_add_func ("/document-loader/end-line-stripping", test_end_line_stripping);
 	g_test_add_func ("/document-loader/end-new-line-detection", test_end_new_line_detection);
 	g_test_add_func ("/document-loader/begin-new-line-detection", test_begin_new_line_detection);
